Package: iemisctext
Title: Irucka Embry's Miscellaneous Text Collection
Version: 1.0.1
Depends: R (>= 3.5.0)
Suggests: install.load, tm, knitr, rmarkdown, xopen, spelling, formatR,
        data.table, ggwordcloud, cffr, bibtex (>= 0.5.0)
Author: Irucka Embry [aut, cre]
Maintainer: Irucka Embry <iembry@ecoccs.com>
Description: An eclectic collection of short stories and poetry with topics on
    climate strange, connecting the geopolitical dots, the myth of us versus
    them, and the idiocy of war. Please refer to the COPYRIGHTS file and the
    text_citation.cff file for the reference copyright information and for the
    complete citations of the reference sources, respectively.
URL: https://gitlab.com/iembry/iemisctext
BugReports: https://gitlab.com/iembry/iemisctext/-/issues
License: Artistic License 2.0
Copyright: file COPYRIGHTS
Language: en-US
Encoding: UTF-8
LazyData: true
LazyDataCompression: xz
VignetteBuilder: knitr
RoxygenNote: 7.3.1
NeedsCompilation: no
Packaged: 2024-05-31 17:51:48 UTC; xbyri
Repository: CRAN
Date/Publication: 2024-06-01 10:33:22 UTC
Built: R 4.6.0; ; 2026-04-25 19:39:03 UTC; unix
