## ----eval = FALSE, tidy = TRUE------------------------------------------------
#  install.packages(c("iemisctext", "xopen"))
#  # install the packages and their dependencies (including any system dependencies)

## ----eval = FALSE, tidy = TRUE------------------------------------------------
#  # load the required packages
#  install.load::load_package("iemisctext", "xopen")
#  # load needed packages using the load_package function from the install.load package (it is assumed that you have already installed these packages)

## ----eval = FALSE-------------------------------------------------------------
#  
#  xopen(system.file("texts", "pdf", "Connect_the_Dots.pdf", package = "iemisctext"))
#  

## ----eval = FALSE-------------------------------------------------------------
#  
#  xopen(system.file("texts", "pdf", "Appeal-womanhood-throughout-the-world.pdf",
#  package = "iemisctext"))
#  

## ----eval = FALSE-------------------------------------------------------------
#  
#  xopen(system.file("texts", "pdf", "The-War-Prayer.pdf", package = "iemisctext"))
#  

## ----eval = FALSE-------------------------------------------------------------
#  
#  xopen(system.file("texts", "pdf", "War-Is-A-Racket.pdf", package = "iemisctext"))
#  

## ----eval = FALSE-------------------------------------------------------------
#  
#  xopen(system.file("texts", "pdf", "The-Mask-of-Anarchy.pdf", package = "iemisctext"))
#  

## ----eval = FALSE-------------------------------------------------------------
#  
#  xopen(system.file("texts", "pdf", "Untitled_Us-versus-Them-or-People-Screwing-over-Other-People.pdf"
#  , package = "iemisctext"))
#  

## ----eval = FALSE-------------------------------------------------------------
#  
#  xopen(system.file("texts", "pdf", "Untitled_Climate-Strange.pdf", package = "iemisctext"))
#  

