---
title: "iemisctext: PDF Version of Written Pieces"
author: "Irucka Embry"
date: "`r Sys.Date()`"
lang: en-us
urlcolor: blue
output:
  rmarkdown::pdf_document:
    highlight: kate
    toc: true
    latex_engine: xelatex
vignette: >
  %\VignetteIndexEntry{iemisctext PDF Version of Written Pieces}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

\bigskip

## Install the packages

Note: If you would like to view the PDFs, you will need to copy and paste the following command in R first to make sure you have all the packages and their dependencies installed:  

```{r eval = FALSE, tidy = TRUE}
install.packages(c("iemisctext", "xopen"))
# install the packages and their dependencies (including any system dependencies)
```

\bigskip
\bigskip

## Load the packages

Note: If you would like to view the PDFs, you will need to copy and paste the following commands in R first to make sure you have all the packages loaded:  

```{r eval = FALSE, tidy = TRUE}
# load the required packages
install.load::load_package("iemisctext", "xopen")
# load needed packages using the load_package function from the install.load package (it is assumed that you have already installed these packages)
```

\bigskip
\bigskip

# View PDF version of each written piece

If you would like to view the PDFs, copy-and-paste the following R code into the R console:  

```{r eval = FALSE}

xopen(system.file("texts", "pdf", "Connect_the_Dots.pdf", package = "iemisctext"))

```

```{r eval = FALSE}

xopen(system.file("texts", "pdf", "Appeal-womanhood-throughout-the-world.pdf",
package = "iemisctext"))

```

```{r eval = FALSE}

xopen(system.file("texts", "pdf", "The-War-Prayer.pdf", package = "iemisctext"))

```

```{r eval = FALSE}

xopen(system.file("texts", "pdf", "War-Is-A-Racket.pdf", package = "iemisctext"))

```

```{r eval = FALSE}

xopen(system.file("texts", "pdf", "The-Mask-of-Anarchy.pdf", package = "iemisctext"))

```

```{r eval = FALSE}

xopen(system.file("texts", "pdf", "Untitled_Us-versus-Them-or-People-Screwing-over-Other-People.pdf"
, package = "iemisctext"))

```

```{r eval = FALSE}

xopen(system.file("texts", "pdf", "Untitled_Climate-Strange.pdf", package = "iemisctext"))

```

\bigskip
\bigskip

# EcoC²S Links

EcoC²S Home -- https://www.ecoccs.com/  
About EcoC²S -- https://www.ecoccs.com/about-ecoc2s.html  
Services -- https://www.ecoccs.com/services.html  
1 Stop Shop -- https://www.ecoccs.com/other-biz.html  
Products -- https://www.questionuniverse.com/products.html  
Media -- https://www.ecoccs.com/media.html  
Resources -- https://www.ecoccs.com/resources.html  
R Trainings and Resources provided by EcoC²S (Irucka Embry, E.I.T.) -- https://www.ecoccs.com/rtraining.html  

\bigskip
\bigskip

# Copyright and License

All R code written by Irucka Embry is distributed under the GPL-3 (or later) license, see the [GNU General Public License {GPL} page](https://www.gnu.org/licenses/gpl-3.0.html).  

All written content originally created by Irucka Embry is copyrighted under the Creative Commons Attribution-ShareAlike 4.0 International license. All other written content retains the copyright of the original author(s).  

This work is licensed under a [Creative Commons Attribution-ShareAlike 4.0 International license](https://creativecommons.org/licenses/by-sa/4.0/).  
